@@ -6,10 +6,11 @@ from .GraphQLType import GraphQLType
 from .QueryBuilder import QueryBuilder
 from .MutationBuilder import MutationBuilder
 from._mutation_runners import (
-  create
+    create,
+    save_multi_create
 )
 
 # * Package name:
 name = 'gstorm'
 # * required here for pypi upload exceptions:
-__version__ = "0.4.10"
+__version__ = "0.5.0"
